@@ -31,7 +31,7 @@ class ButtonMenu(BaseMenu):
         return getattr(self, '_data', {})
 
     def set_data(self, data: Dict) -> 'ButtonMenu':
-        """Sets a dictionary up for persistant state data. Returns itself for fluent-style chaining."""
+        """Sets a dictionary up for persistent state data. Returns itself for fluent-style chaining."""
         self._data = data
 
         return self
@@ -41,7 +41,7 @@ class ButtonMenu(BaseMenu):
         return button == self.input
 
     async def open(self):
-        """The entry point to a new TextMenu instance; starts the main menu loop.
+        """The entry point to a new ButtonMenu instance; starts the main menu loop.
         Manages gathering user input, basic validation, sending messages, and cancellation requests."""
         try:
             self._validate_buttons()
@@ -66,7 +66,7 @@ class ButtonMenu(BaseMenu):
                         await self.output.remove_reaction(self.input, self.ctx.author)
 
                 # refresh our message content with the reactions added
-                self.output = await self.ctx.channel.fetch_message(self.output.id)
+                self.output = await self.destination.fetch_message(self.output.id)
 
                 self.input = await self._get_reaction_add()
 
@@ -119,10 +119,8 @@ class ButtonMenu(BaseMenu):
     def _check_reaction(self, event: RawReactionActionEvent) -> bool:
         """Returns true if the author is the person who reacted and the message ID's match. Checks the pages buttons."""
         # cursed code, not sure how else to cover all cases though; watch for performance issues
-        return (event.member is not None
-                and event.user_id == self.ctx.author.id
+        return (event.user_id == self.ctx.author.id
                 and event.message_id == self.output.id
-                and event.member.bot is False
                 and any(event.emoji.name == btn
                         for btn in [(reaction.emoji.name if isinstance(reaction.emoji, Emoji) else reaction.emoji)
                                     if isinstance(reaction, Reaction) else reaction
@@ -145,26 +143,29 @@ class ButtonMenu(BaseMenu):
             if len(page.buttons_list) > 5:
                 logging.warning('Adding more than 5 buttons to a page at once may result in discord.py throttling the bot client.')
 
-            for button in page.buttons_list:
-                if isinstance(button, (Emoji, PartialEmoji)):
-                    continue
-
-                if isinstance(button, str):
-                    # split the str and test if the value between ':' is in the bot list
-                    _test = button.split(':')
-                    if len(_test) > 1:
-                        if _test[1] in [e.name for e in self.ctx.bot.emojis]:
-                            continue
-
-                    # check by key; faster than iterating over the list w/ for loop
-                    _test = emoji.UNICODE_EMOJI_ALIAS.get(button, None)
-                    if _test:
-                        continue
-
-                raise ButtonsError(f'Invalid Emoji or unicode string: {button}')
+            self._check_buttons(page.buttons_list)
 
         if self.page.on_fail_event:
             raise EventError('A ButtonMenu can not capture an `on_fail` event.')
 
         if _cb_count < len(self.pages) - 1:
             raise EventError(f'ButtonMenu missing `on_next` captures. Expected {len(self.pages) - 1}, found {_cb_count}.')
+
+    def _check_buttons(self, buttons_list):
+        for button in buttons_list:
+            if isinstance(button, (Emoji, PartialEmoji)):
+                continue
+
+            if isinstance(button, str):
+                # split the str and test if the value between ':' is in the bot list
+                _test = button.split(':')
+                if len(_test) > 1:
+                    if _test[1] in [e.name for e in self.ctx.bot.emojis]:
+                        continue
+
+                # check by key; faster than iterating over the list w/ for loop
+                _test = emoji.UNICODE_EMOJI_ALIAS.get(button, None)
+                if _test:
+                    continue
+
+            raise ButtonsError(f'Invalid Emoji or unicode string: {button}')
